@@ -186,7 +186,7 @@ def create_loop(clip_path, loop_duration, can_loopable = True):
         clip.close()
         if clip_duration > loop_duration:
             return clip_path
-        times = int(math.ceil(loop_duration /clip_duration))
+        times = int(math.ceil(loop_duration /clip_duration))+1
         # print(times)
         file_merg_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()))
         final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final-' + os.path.basename(clip_path))
